# Pygame_spiel: Pygame-based UI to play board Reinforcement Learning games from OpenSpiel
PygameSpiel is a [Pygame](https://www.pygame.org)-based library to play board games from the library [OpenSpiel](https://github.com/google-deepmind/open_spiel) against AI algorithms.


Pygame_spiel provides a graphical UI interface to play games from the library [OpenSpiel](https://github.com/google-deepmind/open_spiel). While by default Pygame_spiel allows to play against a few existing algorithms from OpenSpiel, it also enables users who are working with OpenSpiel to quickly test new algorithms. With this in mind, Pygame_spiel offers the possibility to plugin new BOTs in runtime for quick testing.

## Index
* [Installation](docs/installation.md)
* [Get started](docs/get_started.md)

## Overview

Use your mouse to select the cell (tic tac toe) or select pawn and destination cell (breakthrough).

![breakthrough_tic_tac_toe](https://github.com/giogix2/pygame_spiel/assets/5859539/dd5f8709-f383-497e-8317-a113ca50d1e7)

## Version 1.0.0
Games currently available: 
* Breakthrough
* Tic Tac Toe

AI algorithms available:
* mcts, DQN (currently only for breakthrough)

**more to come...**
